# Hello World

Simple package, returns "Hello, World!".

## Installation

Code in order to install the package.

```bash
pip install helloworld
```

## Usage

Example code in order to use the package.

```python
from helloworld import helloworld

# generate "Hello, World!"
helloworld.hello()
```
